pub fn default_rate_limiter() -> Arc<RateLimiter> ⓘExpand description
Create a rate limiter with the default capacity of
DEFAULT_RATE_LIMIT requests per second.
pub fn default_rate_limiter() -> Arc<RateLimiter> ⓘCreate a rate limiter with the default capacity of
DEFAULT_RATE_LIMIT requests per second.