#[non_exhaustive]pub enum BuilderError {
InvalidPort {
port: u16,
reason: String,
},
InvalidEventCapacity {
capacity: usize,
reason: String,
},
InvalidRecorderCapacity {
capacity: usize,
reason: String,
},
InvalidEvalTimeout {
timeout_secs: u64,
reason: String,
},
}Expand description
Errors that can occur when building the Victauri plugin via crate::VictauriBuilder.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidPort
The configured port is invalid (e.g., port 0).
InvalidEventCapacity
The event log capacity is out of the valid range.
InvalidRecorderCapacity
The recorder capacity is out of the valid range.
InvalidEvalTimeout
The eval timeout is out of the valid range.