init

Function init 

pub fn init<R: Runtime>() -> TauriPlugin<R>
it always logs a prominent startup banner, so it can never run silently.

For custom configuration, use VictauriBuilder::new().port(8080).build().

Panics

Panics if the default builder configuration is invalid (this is a bug).