FaultConfig

Struct FaultConfig 

pub struct FaultConfig {
    pub command: String,
    pub fault_type: FaultType,
    pub trigger_count: u64,
    pub max_triggers: u64,
    pub created_at: Instant,
}
Configuration for a single fault injection rule.

Fields

command: String

Target command name.

fault_type: FaultType

Type of fault to inject.

trigger_count: u64

Number of times this fault has been triggered.

max_triggers: u64

Maximum number of times to trigger (0 = unlimited).

created_at: Instant

When this fault was created.

Implementations

Source

impl FaultConfig

pub fn should_trigger_at(&self, now: Instant) -> bool

Whether this fault should still trigger, evaluated at now. A fault is inert once it is older than FAULT_TTL or has hit max_triggers.

pub fn should_trigger(&self) -> bool

Check if this fault should still trigger right now.