start_server

Function start_server 

pub async fn start_server<R: Runtime>(
    app_handle: AppHandle<R>,
    state: Arc<VictauriState>,
    port: u16,
    shutdown_rx: Receiver<bool>,
) -> Result<()>
Start the MCP server on the given port with default options (no auth token).

Errors

Returns an error if the server fails to bind to the requested port (or any port in the fallback range), or if the server exits unexpectedly.