start_server_with_options

Function start_server_with_options 

pub async fn start_server_with_options<R: Runtime>(
    app_handle: AppHandle<R>,
    state: Arc<VictauriState>,
    port: u16,
    auth_token: Option<String>,
    shutdown_rx: Receiver<bool>,
) -> Result<()>
Start the MCP server on the given port with an optional auth token.

Errors

Returns an error if the server fails to bind to the requested port (or any port in the fallback range), or if the server exits unexpectedly.