pub struct VerifyStateParams {
pub frontend_expr: String,
pub backend_state: Option<Value>,
pub backend_command: Option<String>,
pub backend_args: Option<Value>,
pub webview_label: Option<String>,
}Expand description
Parameters for the verify_state tool.
Fields
frontend_expr: StringJavaScript expression that returns the frontend state object to compare.
backend_state: Option<Value>Backend state as a JSON object to compare against.
Either this or backend_command must be provided.
backend_command: Option<String>Tauri command to invoke to fetch backend state for comparison.
The command result is used as the backend state. Mutually exclusive with backend_state.
backend_args: Option<Value>Arguments for the backend_command, if any.
webview_label: Option<String>Target webview label.