pub fn default_rate_limiter() -> Arc<RateLimiterState> ⓘExpand description
Create a rate limiter with the default capacity of 1000 requests per second.
pub fn default_rate_limiter() -> Arc<RateLimiterState> ⓘCreate a rate limiter with the default capacity of 1000 requests per second.