pub fn query(
db_path: &Path,
sql: &str,
params: &[Value],
max_rows: Option<usize>,
) -> Result<Value, String>Expand description
Execute a read-only SQL query against a SQLite database.
Errors
Returns an error if the query is not read-only, the database cannot be opened, or the query fails.