MCP server, tool handler, and parameter types.
Structs
- CssParams
- Parameters for the compound
csstool (inject, remove). - Eval
JsParams - Parameters for the
eval_jstool. - Find
Elements Params - Parameters for the
find_elementstool. - Ghost
Command Params - Parameters for the
detect_ghost_commandstool. - Input
Params - Parameters for the compound
inputtool (fill,type_text,press_key). - Inspect
Params - Parameters for the compound
inspecttool (styles, bounding boxes, highlight, a11y, perf). - Interact
Params - Parameters for the compound
interacttool (click, hover, focus, scroll, select). - Invoke
Command Params - Parameters for the
invoke_commandtool. - IpcIntegrity
Params - Parameters for the
check_ipc_integritytool. - Logs
Params - Parameters for the compound
logstool (console, network, ipc, navigation, dialogs, events). - Navigate
Params - Parameters for the compound
navigatetool (go_to,go_back, history, dialogs). - Recording
Params - Parameters for the compound
recordingtool (start, stop, checkpoint, replay, export, import). - Registry
Params - Parameters for the
get_registrytool. - Resolve
Command Params - Parameters for the
resolve_commandtool. - Screenshot
Params - Parameters for the
screenshottool. - Semantic
Assert Params - Parameters for the
semantic_asserttool. - Snapshot
Params - Parameters for the
snapshottool. - Storage
Params - Parameters for the compound
storagetool (get, set, delete,get_cookies). - Verify
State Params - Parameters for the
verify_statetool. - Victauri
McpHandler - MCP tool handler that dispatches tool calls to the webview bridge and state.
- Wait
ForParams - Parameters for the
wait_fortool. - Window
Params - Parameters for the compound
windowtool (get_state, list, manage, resize, move, title).
Enums
- CssAction
- Action for the compound
csstool. - Dialog
Action - Action to take on a browser dialog.
- Dialog
Type - Browser dialog type for dialog response configuration.
- Input
Action - Action for the compound
inputtool. - Inspect
Action - Action for the compound
inspecttool. - Interact
Action - Action for the compound
interacttool. - Logs
Action - Action for the compound
logstool. - Manage
Action - Window management sub-action for the
manageaction. - Navigate
Action - Action for the compound
navigatetool. - Recording
Action - Action for the compound
recordingtool. - Snapshot
Format - Output format for DOM snapshots.
- Storage
Action - Action for the compound
storagetool. - Storage
Type - Web storage type for browser storage operations.
- Wait
Condition - Condition to poll for in the
wait_fortool. - Window
Action - Action for the compound
windowtool.
Functions
- build_
app - Build an Axum router for the MCP server with default options (no auth token).
- build_
app_ full - Build an Axum router with full control over auth token and rate limiter.
- build_
app_ with_ options - Build an Axum router for the MCP server with an optional auth token and rate limiter.
- parse_
bridge_ event - Parse a single bridge event JSON value into an
AppEvent. - start_
server - Start the MCP server on the given port with default options (no auth token).
- start_
server_ with_ options - Start the MCP server on the given port with an optional auth token.