MCP server, tool handler, and parameter types.
Structs
- Victauri
McpHandler - MCP tool handler that dispatches tool calls to the webview bridge and state.
Functions
- build_
app - Build an Axum router for the MCP server with default options (no auth token).
- build_
app_ full - Build an Axum router with full control over auth token and rate limiter.
- build_
app_ with_ options - Build an Axum router for the MCP server with an optional auth token and rate limiter.
- parse_
bridge_ event - Parse a single bridge event JSON value into an
AppEvent. - start_
server - Start the MCP server on the given port with default options (no auth token).
- start_
server_ with_ options - Start the MCP server on the given port with an optional auth token.