Module mcp

Module mcp 

MCP server, tool handler, and parameter types.

Structs

VictauriMcpHandler
MCP tool handler that dispatches tool calls to the webview bridge and state.

Functions

build_app
Build an Axum router for the MCP server with default options (no auth token).
build_app_full
Build an Axum router with full control over auth token and rate limiter.
build_app_with_options
Build an Axum router for the MCP server with an optional auth token and rate limiter.
parse_bridge_event
Parse a single bridge event JSON value into an AppEvent.
start_server
Start the MCP server on the given port with default options (no auth token).
start_server_with_options
Start the MCP server on the given port with an optional auth token.